Documentation
¶
Index ¶
Constants ¶
const ( ExitOK = 0 ExitError = 1 ExitBadArgs = 2 ExitNotFound = 3 ExitAuth = 4 ExitForbidden = 4 ExitConfirm = 5 ExitCancelled = 5 ExitConflict = 6 ExitRateLimit = 7 ExitNetwork = 7 ExitTimeout = 8 ExitCIFailed = 6 // pipeline/job wait finished in a non-success terminal state )
Exit codes for machine-readable error classification.
Variables ¶
var ErrSilent = errors.New("")
ErrSilent indicates the error has been printed; cobra should not print again.
Functions ¶
func ExecuteContext ¶
ExecuteContext runs the root command with the given context (e.g. signal.NotifyContext).
func LastExitCode ¶
func LastExitCode() int
LastExitCode returns the exit code from the last command execution.
Types ¶
This section is empty.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.