cmd

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 5, 2026 License: MIT Imports: 35 Imported by: 0

Documentation

Index

Constants

const (
	ExitOK        = 0
	ExitBadArgs   = 2
	ExitAuth      = 3
	ExitNotFound  = 4
	ExitForbidden = 5
	ExitRateLimit = 6
	ExitNetwork   = 7
	ExitTimeout   = 8
	ExitCIFailed  = 9  // pipeline/job wait finished in a non-success terminal state
	ExitCancelled = 10 // user cancelled or confirmation not provided
)

Exit codes for machine-readable error classification.

Variables

var ErrSilent = errors.New("")

ErrSilent indicates the error has been printed; cobra should not print again.

Functions

func Execute

func Execute() error

Execute runs the root command with a background context.

func ExecuteContext

func ExecuteContext(ctx context.Context) error

ExecuteContext runs the root command with the given context (e.g. signal.NotifyContext).

func LastExitCode

func LastExitCode() int

LastExitCode returns the exit code from the last command execution.

Types

This section is empty.

Directories

Path Synopsis

Jump to