Documentation
¶
Index ¶
Constants ¶
const ( ExitOK = 0 ExitBadArgs = 2 ExitAuth = 3 ExitNotFound = 4 ExitForbidden = 5 ExitRateLimit = 6 ExitNetwork = 7 ExitTimeout = 8 ExitCIFailed = 9 // pipeline/job wait finished in a non-success terminal state ExitCancelled = 10 // user cancelled or confirmation not provided )
Exit codes for machine-readable error classification.
Variables ¶
var ErrSilent = errors.New("")
ErrSilent indicates the error has been printed; cobra should not print again.
Functions ¶
func ExecuteContext ¶
ExecuteContext runs the root command with the given context (e.g. signal.NotifyContext).
func LastExitCode ¶
func LastExitCode() int
LastExitCode returns the exit code from the last command execution.
Types ¶
This section is empty.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.